@@ -1,22 +1,23 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from . import ArithmeticUnit
+from . import UnaryOperation
 
 
-class bitrev(ArithmeticUnit):
+class bitrev(UnaryOperation):
     """
     Reverse the bits of every block.
     """
     @staticmethod
     def operate(arg): pass
 
-    def __init__(self, *args, **kw):
+    def __init__(self, bigendian=False, blocksize=1):
         """
         Unreadable bit reversal operations due to:
         https://graphics.stanford.edu/~seander/bithacks.html#ReverseByteWith64BitsDiv
         https://graphics.stanford.edu/~seander/bithacks.html#ReverseParallel
         """
-        super().__init__(*args, **kw)
+        super().__init__(bigendian=bigendian, blocksize=blocksize)
+
         if self.bytestream:
             self.operate = lambda v: ((v * 0x202020202) & 0x10884422010) % 1023
         elif self.args.blocksize in (2, 4, 8):
