@@ -20,7 +20,10 @@ class pesig(Unit):
         pe = PE(data=data, fast_load=True)
         pe.parse_data_directories(directories=[self._SECDIRID])
         security = pe.OPTIONAL_HEADER.DATA_DIRECTORY[self._SECDIRID]
-
+        self.log_info(F'signature offset: 0x{security.VirtualAddress:08X}')
+        self.log_info(F'signature length: 0x{security.Size:08X}')
+        if security.VirtualAddress == 0 or security.Size == 0:
+            raise ValueError(F'IMAGE_DIRECTORY_ENTRY_SECURITY ({self._SECDIRID}) is corrupt.')
         sgnoff = security.VirtualAddress + 8
         sgnend = sgnoff + security.Size
         length, revision, certtype = unpack('<IHH', data[sgnoff - 8:sgnoff])
