@@ -25,6 +25,7 @@ class cm(Unit):
         index   : arg.switch('-I', help='index of the chunk in the current frame') = TrueWhenNoArgumentsGiven,
         ext     : arg.switch('-F', help='guess file extension') = False,
         entropy : arg.switch('-E', help='compute data entropy') = False,
+        ic      : arg.switch('-C', help='compute the index of coincidence') = False,
         sha1    : arg.switch('-1', help='compute hash: SHA-1') = False,
         sha256  : arg.switch('-2', help='compute hash: SHA-256') = False,
         crc32   : arg.switch('-3', help='compute hash: CRC32') = False,
@@ -36,6 +37,7 @@ class cm(Unit):
             'index'   : index,
             'ext'     : ext,
             'entropy' : entropy,
+            'ic'      : ic,
             'crc32'   : crc32 or hashes,
             'sha1'    : sha1 or hashes,
             'sha256'  : sha256 or hashes,
@@ -69,6 +71,7 @@ class cm(Unit):
                 'index',
                 'ext',
                 'entropy',
+                'ic',
                 'crc32',
                 'sha1',
                 'sha256',
