@@ -7,6 +7,7 @@ import string
 
 from . import arg, HexViewer
 from ...lib.meta import GetMeta, CustomStringRepresentation, SizeInt
+from ...lib.mime import FileMagicInfo
 from ...lib.types import INF
 from ...lib.tools import isbuffer, lookahead
 
@@ -26,9 +27,14 @@ class peek(HexViewer):
         brief  : arg('-b', group='SIZE', help='One line peek, implies --lines=1.') = False,
         decode : arg('-d', group='MODE', help='Attempt to decode and display printable data.') = False,
         esc    : arg('-e', group='MODE', help='Always peek data as string, escape characters if necessary.') = False,
-        meta   : arg('-m', help='Accumulate metadata that requires scanning the data, such as entropy and file magic.') = False,
+        meta   : arg('-m', group='META', help='Accumulate metadata that requires a full scan.') = False,
+        bare   : arg('-r', group='META', help='Do not list any metadata, only peek the data itself.') = False,
         hexaddr=True, dense=False, expand=False, width=0
     ):
+        if bare and meta:
+            raise ValueError('The bare and meta options are exclusive.')
+        if decode and esc:
+            raise ValueError('The decode and esc options are exclusive.')
         lines = 1 if brief else INF if all else lines
         super(peek, self).__init__(
             brief=brief,
@@ -39,6 +45,7 @@ class peek(HexViewer):
             hexaddr=hexaddr and not brief,
             lines=lines,
             meta=meta,
+            bare=bare,
             width=width,
         )
 
@@ -72,7 +79,7 @@ class peek(HexViewer):
             elif isinstance(value, int):
                 value = F'0x{value:X}'
             elif isinstance(value, float):
-                value = F'{value*100:.2f}%' if 0 <= value <= 1 else F'{value:.4f}'
+                value = F'{value:.4f}'
             metavar = F'{name:>{width}} = {value!s}'
             if len(metavar) > linewidth:
                 metavar = metavar[:linewidth - 3] + '...'
@@ -118,14 +125,17 @@ class peek(HexViewer):
             ]
             remaining -= len(wrapped)
             result.extend(wrapped)
-        return result[:linecount]
+        return result[:abs(linecount)]
 
     def _peeklines(self, data):
 
         codec = None
         lines = None
+        index = None
+        final = True
+
         if data.temp:
-            last, index = data.temp
+            final, index = data.temp
 
         if not self.args.brief:
             padding = 0
@@ -135,37 +145,48 @@ class peek(HexViewer):
                 padding += 6
 
         metrics = self._get_metrics(len(data), self.args.lines, padding)
+        sepsize = metrics.hexdump_width
+        txtsize = metrics.argument or sepsize
 
         if self.args.lines and data:
             if self.args.esc:
-                lines = self._trydecode(data, None, metrics.width)
+                lines = self._trydecode(data, None, txtsize)
             if self.args.decode:
                 for codec in ('UTF8', 'UTF-16LE', 'UTF-16', 'UTF-16BE'):
-                    lines = self._trydecode(data, codec, metrics.width)
+                    lines = self._trydecode(data, codec, txtsize)
                     if lines:
                         codec = codec
                         break
             if lines is None:
                 lines = list(self.hexdump(data, metrics))
+            else:
+                sepsize = txtsize
 
         def separator(title=None):
-            if title is None or metrics.width <= len(title) + 8:
-                return metrics.width * '-'
-            return F'--{title}' + '-' * (metrics.width - len(title) - 2)
+            if title is None or sepsize <= len(title) + 8:
+                return sepsize * '-'
+            return F'--{title}' + '-' * (sepsize - len(title) - 2)
 
         if index is None:
             yield separator()
             return
 
-        if not self.args.brief:
+        if self.args.brief:
+            final = False
+        elif not self.args.bare:
             meta = GetMeta(data)
+            meta['size'] = meta['size']
             if self.args.meta:
-                if meta['magic'] == 'data':
-                    del meta['magic']
                 entropy_percent = meta['entropy'] * 100.0
                 meta['entropy'] = F'{entropy_percent:.2f}%'
-                meta['size'] = meta['size']
-            yield from self._peekmeta(metrics.width, separator(), **meta)
+                meta['ic']
+            else:
+                meta.magic_info = FileMagicInfo(data[:0x1000])
+            if meta['magic'] == 'data':
+                del meta['magic']
+            if index is not None:
+                meta['index'] = index
+            yield from self._peekmeta(metrics.hexdump_width, separator(), **meta)
 
         if lines:
             if not self.args.brief:
@@ -174,14 +195,14 @@ class peek(HexViewer):
             else:
                 brief = next(iter(lines))
                 brief = F'{SizeInt(len(data))!r}: {brief}'
-                if self._idx is not None:
-                    brief = F'#{self._idx:03d}: {brief}'
+                if index is not None:
+                    brief = F'#{index:03d}: {brief}'
                 yield brief
 
-        if last:
+        if final:
             yield separator()
 
     def filter(self, chunks):
-        for last, (index, item) in lookahead(enumerate(chunks)):
-            item.temp = last, index
+        for final, (index, item) in lookahead(enumerate(chunks)):
+            item.temp = final, index
             yield item
