@@ -1,48 +1,9 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 import io
-import uuid
-
-from xml.parsers import expat
-from defusedxml.ElementTree import parse as ParseXML, XMLParser
 
 from .. import arg, Unit
-from ...lib.structures import MemoryFile
-
-
-class ForgivingXMLParser(XMLParser):
-
-    def __init__(self, emap):
-        class ForgivingEntityResolver(dict):
-            def __getitem__(self, key):
-                if key in self:
-                    return dict.__getitem__(self, key)
-                uid = str(uuid.uuid4())
-                self[key] = uid
-                emap[uid] = key
-                return uid
-
-        self.__entity = ForgivingEntityResolver()
-        _ParserCreate = expat.ParserCreate
-
-        try:
-            def PC(encoding, _):
-                parser = _ParserCreate(
-                    encoding, namespace_separator=None)
-                parser.UseForeignDTD(True)
-                return parser
-            expat.ParserCreate = PC
-            super().__init__()
-        finally:
-            expat.ParserCreate = _ParserCreate
-
-    @property
-    def entity(self):
-        return self.__entity
-
-    @entity.setter
-    def entity(self, value):
-        self.__entity.update(value)
+from ...lib.xml import ForgivingParse
 
 
 class ppxml(Unit):
@@ -61,7 +22,7 @@ class ppxml(Unit):
 
         pad = self.args.indent * ' '
         etm = {}
-        dom = ParseXML(MemoryFile(data), parser=ForgivingXMLParser(etm))
+        dom = ForgivingParse(data, etm)
 
         def indent(element, level=0, more_sibs=False):
             """
