@@ -1,36 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from typing import ByteString, Dict, Any
 from codecs import encode, decode
 
 from .. import arg, Unit
-from ...lib.tools import isbuffer
 from ...lib.meta import GetMeta
 
 
-class ByteStringWrapper:
-    def __init__(self, string: ByteString, codec: str):
-        self.string = string
-        self.codec = codec
-
-    def __repr__(self):
-        return self.string.hex().upper()
-
-    def __str__(self):
-        try:
-            return self.string.decode(self.codec)
-        except UnicodeDecodeError:
-            return self.string.decode('ascii', 'backslashreplace')
-
-    @classmethod
-    def FormatMap(cls, chunk: ByteString, codec: str) -> Dict[str, Any]:
-        meta = GetMeta(chunk)
-        for key, value in meta.items():
-            if isbuffer(value):
-                meta[key] = cls(value, codec)
-        return meta
-
-
 class cfmt(Unit):
     """
     Transform a given chunk by applying a format string operation. The positional format
@@ -39,7 +14,7 @@ class cfmt(Unit):
     pipeline can be used to print all files in a given directory with their corresponding
     SHA-256 hash:
 
-        fread ** [| sha256 -t | cfmt {} {path} ]]
+        ef ** [| sha256 -t | cfmt {} {path} ]]
 
     By default, format string arguments are simply joined along a space character to form
     a single format string.
@@ -63,10 +38,6 @@ class cfmt(Unit):
         super().__init__(formats=formats)
 
     def process(self, data):
-        meta = ByteStringWrapper.FormatMap(data, self.codec)
-        data = ByteStringWrapper(data, self.codec)
+        meta = GetMeta(data)
         for spec in self.args.formats:
-            # pre-populate fields in meta dictionary
-            spec.replace('{}', '').format_map(meta)
-        for spec in self.args.formats:
-            yield spec.format(data, **meta).encode(self.codec)
+            yield meta.format(spec, data, self.codec).encode(self.codec)
